@@ -16,7 +16,7 @@ import abc
 import datetime
 
 from dogpile.cache import api
-from dogpile.cache import util as dp_util
+from dogpile import util as dp_util
 from oslo_cache import core
 from oslo_log import log
 from oslo_utils import importutils
@@ -24,7 +24,6 @@ from oslo_utils import timeutils
 import six
 
 from oslo_cache._i18n import _
-from oslo_cache._i18n import _LW
 from oslo_cache import exception
 
 
@@ -422,10 +421,10 @@ class MongoApi(object):
                 existing_value = index_data['expireAfterSeconds']
                 fld_present = 'doc_date' in index_data['key'][0]
                 if fld_present and existing_value > -1 and ttl_seconds < 1:
-                    msg = _LW('TTL index already exists on db collection '
-                              '<%(c_name)s>, remove index <%(indx_name)s> '
-                              'first to make updated mongo_ttl_seconds value '
-                              'to be  effective')
+                    msg = ('TTL index already exists on db collection '
+                           '<%(c_name)s>, remove index <%(indx_name)s> '
+                           'first to make updated mongo_ttl_seconds value '
+                           'to be  effective')
                     LOG.warning(msg, {'c_name': coll_name,
                                       'indx_name': indx_name})
 
