@@ -43,7 +43,6 @@ from oslo_log import log
 from oslo_utils import importutils
 
 from oslo_cache._i18n import _
-from oslo_cache._i18n import _LE
 from oslo_cache import _opts
 from oslo_cache import exception
 
@@ -115,12 +114,24 @@ def _build_cache_config(conf):
         try:
             (argname, argvalue) = argument.split(':', 1)
         except ValueError:
-            msg = _LE('Unable to build cache config-key. Expected format '
-                      '"<argname>:<value>". Skipping unknown format: %s')
+            msg = ('Unable to build cache config-key. Expected format '
+                   '"<argname>:<value>". Skipping unknown format: %s')
             _LOG.error(msg, argument)
             continue
 
         arg_key = '.'.join([prefix, 'arguments', argname])
+        # NOTE(morgan): The handling of the URL data in memcache is bad and
+        # only takes cases where the values are a list. This explicitly
+        # checks for the base dogpile.cache.memcached backend and does the
+        # split if needed. Other backends such as redis get the same
+        # previous behavior. Overall the fact that the backends opaquely
+        # take data and do not handle processing/validation as expected
+        # directly makes for odd behaviors when wrapping dogpile.cache in
+        # a library like oslo.cache
+        if (conf.cache.backend
+                in ('dogpile.cache.memcached', 'oslo_cache.memcache_pool')
+                and argname == 'url'):
+            argvalue = argvalue.split(',')
         conf_dict[arg_key] = argvalue
 
         _LOG.debug('Oslo Cache Config: %s', conf_dict)
@@ -152,7 +163,28 @@ def _sha1_mangle_key(key):
     return util.sha1_mangle_key(key)
 
 
-def create_region():
+def _key_generate_to_str(s):
+    # NOTE(morganfainberg): Since we need to stringify all arguments, attempt
+    # to stringify and handle the Unicode error explicitly as needed.
+    try:
+        return str(s)
+    except UnicodeEncodeError:
+        return s.encode('utf-8')
+
+
+def function_key_generator(namespace, fn, to_str=_key_generate_to_str):
+    # NOTE(morganfainberg): This wraps dogpile.cache's default
+    # function_key_generator to change the default to_str mechanism.
+    return util.function_key_generator(namespace, fn, to_str=to_str)
+
+
+def kwarg_function_key_generator(namespace, fn, to_str=_key_generate_to_str):
+    # NOTE(ralonsoh): This wraps dogpile.cache's default
+    # kwarg_function_key_generator to change the default to_str mechanism.
+    return util.kwarg_function_key_generator(namespace, fn, to_str=to_str)
+
+
+def create_region(function=function_key_generator):
     """Create a region.
 
     This is just dogpile.cache.make_region, but the key generator has a
@@ -163,13 +195,15 @@ def create_region():
         You must call :func:`configure_cache_region` with this region before
         a memoized method is called.
 
+    :param function: function used to generate a unique key depending on the
+                     arguments of the decorated function
+    :type function: function
     :returns: The new region.
     :rtype: :class:`dogpile.cache.region.CacheRegion`
 
     """
 
-    return dogpile.cache.make_region(
-        function_key_generator=_function_key_generator)
+    return dogpile.cache.make_region(function_key_generator=function)
 
 
 def configure_cache_region(conf, region):
@@ -277,21 +311,6 @@ def _get_expiration_time_fn(conf, group):
     return get_expiration_time
 
 
-def _key_generate_to_str(s):
-    # NOTE(morganfainberg): Since we need to stringify all arguments, attempt
-    # to stringify and handle the Unicode error explicitly as needed.
-    try:
-        return str(s)
-    except UnicodeEncodeError:
-        return s.encode('utf-8')
-
-
-def _function_key_generator(namespace, fn, to_str=_key_generate_to_str):
-    # NOTE(morganfainberg): This wraps dogpile.cache's default
-    # function_key_generator to change the default to_str mechanism.
-    return util.function_key_generator(namespace, fn, to_str=to_str)
-
-
 def get_memoization_decorator(conf, region, group, expiration_group=None):
     """Build a function based on the `cache_on_arguments` decorator.
 
@@ -313,8 +332,8 @@ def get_memoization_decorator(conf, region, group, expiration_group=None):
 
         import oslo_cache.core
 
-        MEMOIZE = oslo_cache.core.get_memoization_decorator(conf,
-                                                            group='group1')
+        MEMOIZE = oslo_cache.core.get_memoization_decorator(
+            conf, region, group='group1')
 
         @MEMOIZE
         def function(arg1, arg2):
@@ -322,7 +341,7 @@ def get_memoization_decorator(conf, region, group, expiration_group=None):
 
 
         ALTERNATE_MEMOIZE = oslo_cache.core.get_memoization_decorator(
-            conf, group='group2', expiration_group='group3')
+            conf, region, group='group2', expiration_group='group3')
 
         @ALTERNATE_MEMOIZE
         def function2(arg1, arg2):
